@@ -15,11 +15,11 @@ ZHOUYI::ZhanPu - A util of ZHOUYI modules，divination to judge for the future u
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 =head1 SYNOPSIS
 
@@ -89,7 +89,6 @@ sub bugaindex {
 }
 
 =pod
-=head2 function jiegua
 
 the explanations functions - input the guanum and it's 
 changs trend from the yao's yinyang.
@@ -110,6 +109,28 @@ sub jiegua {
     my ( $ogua, $bgua, $myao, $mguo ) = @_;
     my $int = $mguo ? $ogua : $bgua;
     my $msg;
+    if  ($myao eq 'B'){
+        
+         $msg=zhanbu( $ogua, -1 ); 
+         $msg.="变";
+         $msg.=zhanbu( $bgua, -1 );
+
+      }elsif($myao eq 'C') {
+              
+        ( $ogua == 0 )or ( $ogua == 63 )
+              ? ($msg=zhanbu( $ogua, 6 ))
+              : ($msg=zhanbu( $ogua, -1 ))
+
+      }elsif($myao eq 'U') {
+      
+        $msg=zhanbu( $ogua, -1 ) 
+     
+     }else {
+      
+        $msg=zhanbu( $int,  $myao );
+     
+     } 
+=pod
     given ($myao) {
         when ('B') { $msg=zhanbu( $ogua, -1 );  $msg.=zhanbu( $bgua, -1 ); }
         when ('C') {
@@ -121,6 +142,7 @@ sub jiegua {
         when ('U') { $msg=zhanbu( $ogua, -1 ) }
         default    { $msg=zhanbu( $int,  $myao ) }
     }
+=cut
    return $msg;
 }
 
@@ -129,21 +151,34 @@ sub zhanbu {
     my ( $gua, $myao ) = @_;
     my $sint   = sprintf( "%lo", $gua );
     my $reply  = ZhouyiEx( $zy->{ $yi->{$sint} } );
-    my $reply1 = outGua($reply);
+    my $reply1 = outtuan($reply);
+    my ( $replyyao, $syao ) = maixyao( $reply, $myao );
+    my ( $replyxiang, $sxiang ) = maixiang( $reply, $myao ); 
+       $reply1.=$sxiang->[0];
     my $wydsg;
+          
+        if($myao == -1) {
+
+         $wydsg="卦：".$reply1. "\n\n";       
+ 
+        }elsif($myao == 6 ) {
+         $wydsg= "爻：".$syao->[6]."\n".$sxiang->[7];
+        }else {
+         $wydsg= "卦：". $reply1. "\n\n";
+         $wydsg.= "爻：".$replyyao."\n".$replyxiang."\n";
+        }
+=pod
     given ($myao) {
         when (-1) { $wydsg="\n卦：".$reply1. "\n"; }
         when (6) {
-            my ( $replyyao, $syao ) = maixyao( $reply, $myao );
-            $wydsg= "爻：".$syao->[6]."\n"
+            $wydsg= "爻：".$syao->[6]."\n    ".$sxiang->[7];
         }
         default {
-            my ( $replyyao, $syao ) = maixyao( $reply, $myao );
-            $wydsg= "\n卦：". $reply1. "\n";
-            $wydsg.="爻：". $replyyao. "\n"
+            $wydsg= "\n卦：". $reply1. "\n\n";
+            $wydsg.= "爻：".$replyyao."\n   ".$replyxiang."\n";
         }
     }
-   
+=cut   
    return $wydsg;
 
 }
@@ -233,6 +268,16 @@ sub biangua {
 #    print "by : @by", "\n";
 #    print "dy : @dy", "\n";
 
+    my $bunum=scalar @by;
+
+    if($bunum == 1){$maiyao = $by[0]; $maigua = 1}
+    elsif($bunum == 2){ $maiyao = $by[1]; $maigua = 1 }
+    elsif($bunum == 3){ $maiyao = "B";    $maigua = 1 }
+    elsif($bunum == 4){ $maiyao = $dy[0]; $maigua = 0 }
+    elsif($bunum == 5){ $maiyao = $dy[0]; $maigua = 0 }
+    elsif($bunum == 6){ $maiyao = "C";    $maigua = 0 }
+    else {$maiyao = "U";    $maigua = 1 }
+=pod
     given ( scalar @by ) {
         when (1) { $maiyao = $by[0]; $maigua = 1 }
         when (2) { $maiyao = $by[1]; $maigua = 1 }
@@ -242,6 +287,8 @@ sub biangua {
         when (6) { $maiyao = "C";    $maigua = 0 }
         default  { $maiyao = "U";    $maigua = 1 }
     }
+
+=cut
 #    print "Yaobian:", $maiyao, "\n";
 #    print "Guabian:", $maigua, "\n";
 #    print "@bnum",    "\n";
